function [a, lam_S, growth_rel, growth_abs] = DEBIPMShrink_mites(weeks,weekstart,MatrixSize)

% Please cite:

% input: 
% weeks: number of weeks to simulate
% weekstart; % start week from which lambda_s is calculated
% MatrixSize: number of size bins of matrix approximation of DEBIPM

Lmin = 150/1000; % used to define limits of matrix approximation
Lb = 167/1000; % length at birth in mm 
Lm = 1008/1000; % maximum body length in mm 
E_Ystdev=0.1; % sigma(Y)

% DEB parameters 
kappa = 0.082; % fraction energy allocation to respiration (as opposed to reproduction)
mu = 0.03; % background mortality rate
muharvest = 0.69; % 50% of total population is harvested: 0.5 = exp(-muharvest) -> muharvest = -ln(0.5) = 0.69
beta = 151; % to calculate von Bertalanffy growth rate r_b
alpha = -137.8; % to calculate von Bertalanffy growth rate r_b
Rm = 32; % maximum reproduction rate at L_m
E_Y=1; % experienced feeding level
Linf = E_Y*Lm; % ultimate length  
Lp = 0.539*Linf; % length at puberty
rb = 1/(beta + alpha*Linf); % von Bertellanfy growth rate

simrun = zeros(weeks*7,1); for j=1:weeks, simrun (j*7,1) = 1; end % indicate weekly harvesting moments
daystart = 1+weekstart*7; % day on which harvesting starts
simrun(1:daystart-1)=0
tlimit = length(simrun);
vec1 = 0.0005*ones(MatrixSize,1); % starting population vector
popvecAbs = vec1;
for i=1:tlimit, i/tlimit
            
            if simrun(i)==1; harvestcheck = 1; else harvestcheck = 0; end  % 1 = harvest; 0 = no harvest                          
            [S, R, G, D, meshpts] = BigMatrixShrink(MatrixSize,Lmin,Linf,Lp,Rm,Lm,E_Y,E_Ystdev,rb,kappa,Lb,mu, muharvest, harvestcheck);
            kernel = G*S + D*R; 
            % calculate pop growth
         vec1 = kernel * vec1;
         growth_rel1 = sum(vec1);
         growth_rel(i) = growth_rel1;
         popvecAbs = kernel * popvecAbs;
         growth_abs1 = sum(popvecAbs);
         growth_abs(i) = growth_abs1;
         vec1= vec1/growth_rel1;        
end

a=mean(log(growth_rel(daystart:tlimit)))
var_a=var(log(growth_rel(daystart:tlimit)));
CI_a=[a-1.96*sqrt(var_a/tlimit) a+1.96*sqrt(var_a/tlimit)];
lam_S=exp(a);
plot(growth_rel(1:end-1))