#  ANALYSIS OF MALE MORPH EXPRESSION AND MEAN SWITCH POINT

# when exporting data from excel file exclude blanks and FM/SM individuals first.

input<-read.table("C:\\Users\\ismalle1\\Documents\\WERK\\Data\\experimenten\\2015 Jasper Rianne experiments\\Rianne population experiment\\QTsEndOfExperiment.txt",header=T)

library(lme4)

# test for treatment effects on quiescent tritonymph size: is there evolutionary change here?
attach(input)    

inputFHSH <- subset(input,(treatment=="SMr" | treatment=="FMr"))  
attach(inputFHSH)
          
y <-qtsize
model1 <- lmer( y ~ treatment*morph2 + (1|tube) + (1|id_mother))
qqnorm(residuals(model1)) # check if residuals follow Normal distribution
summary(model1)
model1a <- update(model1, ~.- treatment:morph2, verbose=F)
anova(model1,model1a,test="Chi"); 

model2 <- update(model1, ~.- treatment, verbose=F)
anova(model1,model2,test="Chi"); 
# treatment is not marginally not significant
summary(model2)
markov2 <- mcmcsamp(model2,5000); HPDinterval(markov2);
model3 <- update(model2, ~.- morph2, verbose=F)
anova(model2,model3,test="Chi"); 
# no effect of morph
summary(model3)
markov3 <- mcmcsamp(model3,5000); HPDinterval(markov3);
model4 <- update(model3, ~.- morph2, verbose=F)
anova(model3,model4,test="Chi"); 
summary(model3)
# significant difference so FMs and SMs differ from each other:FM>SM

# test for effect of interaction between treatment and quiscent trito size on male morph expression: hence different switchpoints between treatments

detach(input)
y <-morph
# no interaction in this model, following Tomkins et al. 2011
model1 <- glmer( y ~ treatment + qtsize + (1|tube) + (1|id_mother), family=binomial)
summary(model1)
model2 <- update(model1, ~.- treatment)
anova(model1,model2,test="Chi"); 
# no significant effect of treatment
summary(model2)
model3 <- update(model2, ~.- qtsize)
anova(model3,model2,test="Chi"); 
# no significant effect of qsize
mean(y)
sd(y)/sqrt(length(y))

# redo analysis with normalised QT size since QT size differs between treatment
y <-morph
# no interaction in this model, following Tomkins et al. 2011
model1 <- glmer( y ~ treatment + qtsizenorm + (1|tube) + (1|id_mother), family=binomial)
summary(model1)
model2 <- update(model1, ~.- treatment)
anova(model1,model2,test="Chi"); 
# no significant effect of treatment
summary(model2)
model3 <- update(model2, ~.- qtsizenorm)
anova(model3,model2,test="Chi"); 
# no significant effect of qsize
mean(y)
sd(y)/sqrt(length(y))

detach(input)


# analysis of proportion females
y <-propfemales
model1 <- lmer( y ~ treatment + (1|tube) + (1|id_mother), family=binomial, REML=FALSE,control = list(maxIter=100000), verbose =  F)
summary(model1)
model2 <- update(model1, ~.- treatment, verbose=F)
anova(model1,model2,test="Chi"); 
# no treatment effect: proportion of females is on average 0.5239
mean(y); stdError <- sd(y)/sqrt(length(y)); print(stdError)